.. list-table:: Variables from GEFS available in ufs2arco
   :widths: 18 50
   :header-rows: 1

   * - Variable
     - Long Name
   * - ``d2m``
     - 2 metre dewpoint temperature
   * - ``gh``
     - Geopotential height
   * - ``lsm``
     - Land-sea mask
   * - ``orog``
     - Orography
   * - ``q``
     - Specific humidity
   * - ``sh2``
     - 2 metre specific humidity
   * - ``sp``
     - Surface pressure
   * - ``t``
     - Temperature
   * - ``t2m``
     - 2 metre temperature
   * - ``u``
     - U component of wind
   * - ``u10``
     - 10 metre U wind component
   * - ``v``
     - V component of wind
   * - ``v10``
     - 10 metre V wind component
   * - ``w``
     - Vertical velocity
